#!/bin/bash


source ../qpid_test_common_mrg_install/mrg_test_functions.sh

DATE_TIME_START=$(date +%Y%m%d_%H%M%S)
TEMP_FILE=tmp_${DATE_TIME_START}
TEMP_FILE_GLOB=tmp_*

TESTSUITE_DIR="`dirname $0`"
QPIDD_DATADIR="${PWD}/rhts_qpidd/${DATE_TIME_START}"

PREFIX_DIR=/usr/bin
QPIDD_DIR=${TEST_PARAM_RHTS_TEST_QPIDD_DIR:-/usr/sbin}

# set qpidd params
export QPIDD_PORT=5672
QPIDD_TEST_PARAMS="--auth no --log-enable info+"
QPIDD_TRANSCRIPT="qpidd.transcript.log"
QPIDD_LOCK=qpidd.lock
QPIDD_ECODE=qpidd.ecode

COMMON_TRANSCRIPT="common_transcript.log"

NR_OF_LOOPS=100

  # stop all qpidd brokers
  # -------------------------------------------------------------------------
  lognl "Stopping all running qpidd instances..."
  qpidd_stop
  ecode="$?"
  if [ "${ecode}" == "0" -a "${QPIDD_INST_CNT}" == "0" ]; then
    lognl ".qpidd stopped ok"
  else
    lognl ".ERROR:qpidd didn't stop (ecode:${ecode}|qpidd_int_cnt:${QPIDD_INST_CNT})"
    let "ERR_CNT++"
  fi
  
  
  
  # main loop
  for ((i_loop=0; i_loop<${NR_OF_LOOPS}; i_loop++)); do
    
    let "i_loop_p1=${i_loop} + 1"
    lognl "run(B) ${i_loop_p1}/${NR_OF_LOOPS}--------------------------------[err_cnt:${ERR_CNT}]-"
  
    
    # create qpidd data journal storage
    # -----------------------------------------------------------------------
    trasher ${QPIDD_DATADIR}
    mkdir -p ${QPIDD_DATADIR}
    QPIDD_DATADIR_JOURNAL=$(mktemp -d ${QPIDD_DATADIR}/broker.XXXX)
    
    # start qpidd
    # -----------------------------------------------------------------------
    qpidd_start_normal ${QPIDD_PORT} ${QPIDD_DATADIR_JOURNAL} ${QPIDD_TRANSCRIPT} ${QPIDD_TEST_PARAMS}
    
    # wait for qpidd ready
    # -----------------------------------------------------------------------
    qpidd_wait_on_settle ${QPIDD_TRANSCRIPT} "Listening on TCP port" ${QPIDD_LOCK} 20
    if [ "$?" == "0" ]; then
      lognl ".qpidd settled"
    else
      lognl ".ERROR:qpidd not started"
      let "ERR_CNT++"
    fi
    
    
    PERFTEST="perftest"
    # running perftest
    # -----------------------------------------------------------------------
    lognl ".running perftest on bg"
    $(touch ${PERFTEST}.${i_loop_p1}.lock ; ${PERFTEST} --log-enable info+ > ${PERFTEST}.${i_loop_p1}.log 2> ${PERFTEST}.${i_loop_p1}.log ; echo "$?" > ${PERFTEST}.${i_loop_p1}.ecode; rm -f ${PERFTEST}.${i_loop_p1}.lock) &
    
    gen_my_rand_in_range 1 7
    sleep ${MY_RAND}
    
    # verify qpidd is up and running
    # -----------------------------------------------------------------------
    lognl ".qpidd status check"
    qpidd_status
    if [ -e ${QPIDD_LOCK} -a \
        "${QPIDD_INST_CNT}" == "1" -a \
        "${QPIDD_INST_PORT}" == "${QPIDD_INST_PORT}" ]; then
      lognl "..qpidd running fine on port ${QPIDD_INST_PORT} (${QPIDD_INST_CNT} instance[s])"
    else
      lognl "..ERROR:qpidd not running fine! (pid[s]:${QPIDD_INST_PID}, port[s]:${QPIDD_INST_PORT}, inst_cnt:${QPIDD_INST_CNT})"
      let "ERR_CNT++"
    fi
    
    # stopping qpidd
    # -----------------------------------------------------------------------
    lognl ".qpidd stop"
    qpidd_stop
    ecode="$?"
    if [ "${ecode}" == "0" -a "${QPIDD_INST_CNT}" == "0" ]; then
      lognl "..qpidd stopped ok"
    else
      lognl "..ERROR:qpidd didn't stop (ecode:${ecode}|qpidd_int_cnt:${QPIDD_INST_CNT})"
      let "ERR_CNT++"
    fi
    
    # remove qpidd lock
    # -----------------------------------------------------------------------
    lognl ".remove qpidd parent lock (if needed)..."
    trasher ${QPIDD_LOCK}
  
    # logging
    # -----------------------------------------------------------------------
    echo "--- qpidd log --- " >> ${COMMON_TRANSCRIPT}
    cat ${QPIDD_TRANSCRIPT} >> ${COMMON_TRANSCRIPT}
  
    sleep 1
  
  
  done



#           
# 
# for ((i=0;i<100;i++)); do 
#   
#     
#   echo ">${i}<" 
#   qpidd -dp 12345 --data-dir ${PWD}/data --log-enable info+ >> qpidd.log 2>> qpidd.log
#   sleep 10
#   $(perftest -p12345 >> perftest.${i}.log )& 
#   sleep 3 
#   qpidd -qp 12345
#   sleep 5 
# done
# 

# eof

