#!/bin/bash

# Copyright (c) 2008 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Frantisek Reznicek <freznice@redhat.com>


# source used MRG test common functions
# ###########################################################################
source ./mrg_test_functions.sh


# global test variables 
# ###########################################################################
VERSION=1.0                  # test version
RESULT=FAIL                  # FAIL unless test explicitly passes
ERR_CNT=0                    # error counter init
TST_CNT=0                    # test count
OUTPUTFILE="$PWD/$(basename $0).log"
VERBOSE_LEVEL=${TEST_PARAM_RHTS_TEST_VERBOSE_LEVEL:-0}


# Source RHTS environment (. /usr/bin/rhts-environment.sh)
# ###########################################################################
rhts_load_environment


# ###########################################################################
# main - MRG installation or compilation & installation
# ###########################################################################

# ${OUTPUTFILE} logging starts here
{

# install additional packages on top of the default ones
# ###########################################################################
pkgs2install="subversion"
install_packages_yum ${pkgs2install}

# gather additional info
# ###########################################################################
if [ -n "${VERBOSE_LEVEL}" -a "${VERBOSE_LEVEL}" != "0" ]; then
  # basic info
  get_essential_info
  
  # get info about newly installed packages by this test (diff view only)
  get_installed_packages ${RHTS_TEST_MRG_INSTALLED_PACKAGES}
fi


# test additional executables which need to be installed 
# ###########################################################################
tools_to_check="svn g++"
check_tool_install ${tools_to_check}
if [ "$?" != "0" ]; then
  rhts_report_result ${TEST} ${RESULT} 1
  exit 1
fi



# un-installation
# ###########################################################################
lognl "MRG checkout started..."
if [ -n "$1" ]; then
  mrg_src_checkout "$1" "$2"
  ecode="$?"
else
  mrg_src_checkout "${TEST_PARAM_RHTS_TEST_MRG_COMPILE_REVS}"
  ecode="$?"
fi

if [ "${ecode}" != "0" ]; then
  lognl ".ERROR:checkout failed (ecode:${ecode})"
  let "ERR_CNT++"
else
  lognl ".checkout succeeded"
fi


exit 0

lognl "MRG compilation started..."


uninstall_mrg
ecode="$?"

let "TST_CNT++"

if [ "${ecode}" != "0" ]; then
  lognl "MRG compilation failed... see above"
  let "ERR_CNT++"
else
  lognl "MRG compilation OK"
fi


# ###########################################################################
# report results
# ###########################################################################

if [ "${ERR_CNT}" -eq "0" ]; then
  RESULT=PASS
fi

# report results
rhts_report_result ${TEST} ${RESULT} ${ERR_CNT}

} 2>&1 | tee ${OUTPUTFILE}


# ###########################################################################
# end - testing sequence stops here
# ###########################################################################

# ###########################################################################
# eof
# ###########################################################################
